@@ -145,6 +145,14 @@ void error (const char *str) {
 	exit (1);
 }
 
+void error_or_perm (const char *str) {
+
+	if (errno == EPERM)
+		fprintf (stderr, "You have no enough privileges to use "
+				"this traceroute method.");
+	error (str);
+}
+
 
 /*  Set initial parameters according to how we was called   */
 
@@ -571,10 +579,6 @@ int main (int argc, char *argv[]) {
 	ops = tr_get_module (module);
 	if (!ops)  ex_error ("Unknown traceroute module %s", module);
 
-	if (!ops->user && geteuid () != 0)
-	    ex_error ("The specified type of tracerouting "
-			"is allowed for superuser only");
-
 
 	if (!first_hop || first_hop > max_hops)
 		ex_error ("first hop out of range");
